
( function ( blocks, element, blockEditor ) {
    const el = element.createElement,
        registerBlockType = blocks.registerBlockType,
        ServerSideRender = PgServerSideRender,
        InspectorControls = blockEditor.InspectorControls,
        useBlockProps = blockEditor.useBlockProps;
        
    const {__} = wp.i18n;
    const {ColorPicker, TextControl, ToggleControl, SelectControl, Panel, PanelBody, Disabled, TextareaControl, BaseControl} = wp.components;
    const {useSelect} = wp.data;
    const {RawHTML, Fragment} = element;
   
    const {InnerBlocks, URLInputButton, RichText} = wp.blockEditor;
    const useInnerBlocksProps = blockEditor.useInnerBlocksProps || blockEditor.__experimentalUseInnerBlocksProps;
    
    const propOrDefault = function(val, prop, field) {
        if(block.attributes[prop] && (val === null || val === '')) {
            return field ? block.attributes[prop].default[field] : block.attributes[prop].default;
        }
        return val;
    }
    
    const block = registerBlockType( 'flexwebsite/pricing-plan', {
        apiVersion: 2,
        title: 'Pricing plan',
        icon: 'block-default',
        category: 'flex',
        parent: [ 'flexwebsite/pricing' ],

        keywords: [],
        supports: {color: {background: false,text: false,gradients: false,link: false,},typography: {fontSize: false,},anchor: false,align: false,},
        attributes: {
            name: {
                type: 'text',
                default: `Small`,
            },
            subtitle: {
                type: 'text',
                default: `For Individual Users`,
            },
            price_monthly: {
                type: 'text',
                default: `10`,
            },
            price_annual: {
                type: 'text',
                default: `100`,
            },
            button_url: {
                type: 'object',
                default: {post_id: 0, url: '#', title: '', 'post_type': null},
            },
            button_label: {
                type: 'text',
                default: `Get Started Now`,
            }
        },
        example: { attributes: { name: `Small`, subtitle: `For Individual Users`, price_monthly: `10`, price_annual: `100`, button_url: {post_id: 0, url: '#', title: '', 'post_type': null}, button_label: `Get Started Now` } },
        edit: function ( props ) {
            const blockProps = useBlockProps({ className: 'w-full md:w-1/2 lg:w-1/3 p-4' });
            const setAttributes = props.setAttributes; 
            
            
            const innerBlocksProps = useInnerBlocksProps({ className: 'self-start px-8' }, {
                allowedBlocks: [ 'flexwebsite/pricing-plan-feature' ],
                template: [
    [ 'flexwebsite/pricing-plan-feature', {} ],
    [ 'flexwebsite/pricing-plan-feature', {} ],
    [ 'flexwebsite/pricing-plan-feature', {} ],
    [ 'flexwebsite/pricing-plan-feature', {} ]
],
            } );
                            
            
            return el(Fragment, {}, [
                el('div', { ...blockProps }, el('div', { className: 'flex flex-col pt-8 pb-8 h-full bg-coolGray-50 rounded-md shadow-md hover:scale-105 transition duration-500' }, [el('div', { className: 'px-8 text-center' }, [el(RichText, { tagName: 'h3', className: 'mb-2 text-3xl md:text-4xl text-coolGray-800 font-semibold tracking-tighter', value: propOrDefault( props.attributes.name, 'name' ), onChange: function(val) { setAttributes( {name: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] }), el(RichText, { tagName: 'p', className: 'mb-6 text-coolGray-400 font-medium', value: propOrDefault( props.attributes.subtitle, 'subtitle' ), onChange: function(val) { setAttributes( {subtitle: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] }), el('div', { className: 'relative' }, [el('div', { className: 'absolute inset-x-0 mb-6 monthly', 'data-pg-ia-hide': '' }, [el('span', { className: 'relative -top-10 right-1 text-3xl text-coolGray-900 font-bold' }, '$'), el(RichText, { tagName: 'span', className: 'text-6xl md:text-7xl text-coolGray-900 font-semibold tracking-tighter', value: propOrDefault( props.attributes.price_monthly, 'price_monthly' ), onChange: function(val) { setAttributes( {price_monthly: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] }), el('span', { className: 'inline-block ml-1 text-coolGray-500 font-semibold' }, '/mo')]), el('div', { className: 'annual mb-6' }, [el('span', { className: 'relative -top-10 right-1 text-3xl text-coolGray-900 font-bold' }, '$'), el(RichText, { tagName: 'span', className: 'text-6xl md:text-7xl text-coolGray-900 font-semibold tracking-tighter', value: propOrDefault( props.attributes.price_annual, 'price_annual' ), onChange: function(val) { setAttributes( {price_annual: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] }), el('span', { className: 'inline-block ml-1 text-coolGray-500 font-semibold' }, '/year')])]), el(RichText, { tagName: 'a', className: 'inline-block py-4 px-7 mb-8 w-full text-base md:text-lg leading-6 text-green-50 font-medium text-center bg-green-500 hover:bg-green-600 focus:ring-2 focus:ring-green-500 focus:ring-opacity-50 rounded-md shadow-sm', href: '#', value: propOrDefault( props.attributes.button_label, 'button_label' ), onChange: function(val) { setAttributes( {button_label: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] })]), el('ul', { ...innerBlocksProps })])),                        
                
                    el( InspectorControls, {},
                        [
                            
                            el(Panel, {},
                                el(PanelBody, {
                                    title: __('Block properties')
                                }, [
                                    
                                    el(TextControl, {
                                        value: props.attributes.name,
                                        help: __( '' ),
                                        label: __( 'Name' ),
                                        onChange: function(val) { setAttributes({name: val}) },
                                        type: 'text'
                                    }),
                                    el(TextControl, {
                                        value: props.attributes.subtitle,
                                        help: __( '' ),
                                        label: __( 'Subtitle' ),
                                        onChange: function(val) { setAttributes({subtitle: val}) },
                                        type: 'text'
                                    }),
                                    el(TextControl, {
                                        value: props.attributes.price_monthly,
                                        help: __( '' ),
                                        label: __( 'Price monthly' ),
                                        onChange: function(val) { setAttributes({price_monthly: val}) },
                                        type: 'text'
                                    }),
                                    el(TextControl, {
                                        value: props.attributes.price_annual,
                                        help: __( '' ),
                                        label: __( 'Price annual' ),
                                        onChange: function(val) { setAttributes({price_annual: val}) },
                                        type: 'text'
                                    }),
                                    pgUrlControl('button_url', setAttributes, props, 'Button url', '', null ),
                                    el(TextControl, {
                                        value: props.attributes.button_label,
                                        help: __( '' ),
                                        label: __( 'Button label' ),
                                        onChange: function(val) { setAttributes({button_label: val}) },
                                        type: 'text'
                                    }),    
                                ])
                            )
                        ]
                    )                            

            ]);
        },

        save: function(props) {
            const blockProps = useBlockProps.save({ className: 'w-full md:w-1/2 lg:w-1/3 p-4' });
            return el('div', { ...blockProps }, el('div', { className: 'flex flex-col pt-8 pb-8 h-full bg-coolGray-50 rounded-md shadow-md hover:scale-105 transition duration-500' }, [el('div', { className: 'px-8 text-center' }, [el(RichText.Content, { tagName: 'h3', className: 'mb-2 text-3xl md:text-4xl text-coolGray-800 font-semibold tracking-tighter', value: propOrDefault( props.attributes.name, 'name' ) }), el(RichText.Content, { tagName: 'p', className: 'mb-6 text-coolGray-400 font-medium', value: propOrDefault( props.attributes.subtitle, 'subtitle' ) }), el('div', { className: 'relative' }, [el('div', { className: 'absolute inset-x-0 mb-6 monthly', 'data-pg-ia-hide': '' }, [el('span', { className: 'relative -top-10 right-1 text-3xl text-coolGray-900 font-bold' }, '$'), el(RichText.Content, { tagName: 'span', className: 'text-6xl md:text-7xl text-coolGray-900 font-semibold tracking-tighter', value: propOrDefault( props.attributes.price_monthly, 'price_monthly' ) }), el('span', { className: 'inline-block ml-1 text-coolGray-500 font-semibold' }, '/mo')]), el('div', { className: 'annual mb-6' }, [el('span', { className: 'relative -top-10 right-1 text-3xl text-coolGray-900 font-bold' }, '$'), el(RichText.Content, { tagName: 'span', className: 'text-6xl md:text-7xl text-coolGray-900 font-semibold tracking-tighter', value: propOrDefault( props.attributes.price_annual, 'price_annual' ) }), el('span', { className: 'inline-block ml-1 text-coolGray-500 font-semibold' }, '/year')])]), el(RichText.Content, { tagName: 'a', className: 'inline-block py-4 px-7 mb-8 w-full text-base md:text-lg leading-6 text-green-50 font-medium text-center bg-green-500 hover:bg-green-600 focus:ring-2 focus:ring-green-500 focus:ring-opacity-50 rounded-md shadow-sm', href: propOrDefault( props.attributes.button_url.url, 'button_url', 'url' ), value: propOrDefault( props.attributes.button_label, 'button_label' ) })]), el('ul', { className: 'self-start px-8' }, el(InnerBlocks.Content, { allowedBlocks: [ 'flexwebsite/pricing-plan-feature' ] }))]));
        }                        

    } );
} )(
    window.wp.blocks,
    window.wp.element,
    window.wp.blockEditor
);                        
