
( function ( blocks, element, blockEditor ) {
    const el = element.createElement,
        registerBlockType = blocks.registerBlockType,
        ServerSideRender = PgServerSideRender,
        InspectorControls = blockEditor.InspectorControls,
        useBlockProps = blockEditor.useBlockProps;
        
    const {__} = wp.i18n;
    const {ColorPicker, TextControl, ToggleControl, SelectControl, Panel, PanelBody, Disabled, TextareaControl, BaseControl} = wp.components;
    const {useSelect} = wp.data;
    const {RawHTML, Fragment} = element;
   
    const {InnerBlocks, URLInputButton, RichText} = wp.blockEditor;
    const useInnerBlocksProps = blockEditor.useInnerBlocksProps || blockEditor.__experimentalUseInnerBlocksProps;
    
    const propOrDefault = function(val, prop, field) {
        if(block.attributes[prop] && (val === null || val === '')) {
            return field ? block.attributes[prop].default[field] : block.attributes[prop].default;
        }
        return val;
    }
    
    const block = registerBlockType( 'flexwebsite/steps', {
        apiVersion: 2,
        title: 'Steps',
        icon: 'block-default',
        category: 'flex',
        keywords: [],
        supports: {color: {background: false,text: false,gradients: false,link: false,},typography: {fontSize: false,},anchor: false,align: false,},
        attributes: {
            section_id: {
                type: 'text',
                default: '',
            },
            image: {
                type: 'object',
                default: {id: 0, url: (pg_project_data_flexwebsite ? pg_project_data_flexwebsite.url : '') + 'images/stock.png', size: ''},
            },
            label: {
                type: 'text',
                default: `How it works`,
            },
            title: {
                type: 'text',
                default: `Gain more insight into how people use your`,
            }
        },
        example: { attributes: { section_id: '', image: {id: 0, url: (pg_project_data_flexwebsite ? pg_project_data_flexwebsite.url : '') + 'images/stock.png', size: ''}, label: `How it works`, title: `Gain more insight into how people use your` } },
        edit: function ( props ) {
            const blockProps = useBlockProps({ className: 'py-24 bg-white overflow-hidden', style: { backgroundPosition: 'center',backgroundImage: 'url(\'' + (pg_project_data_flexwebsite ? pg_project_data_flexwebsite.url : '') + 'images/pattern-white.svg\')' }, id: propOrDefault( props.attributes.section_id, 'section_id' ) });
            const setAttributes = props.setAttributes; 
            
            props.image = useSelect(function( select ) {
                return {
                    image: props.attributes.image.id ? select('core').getMedia(props.attributes.image.id) : undefined
                };
            }, [props.attributes.image] ).image;
            
            const innerBlocksProps = useInnerBlocksProps({ className: 'flex flex-wrap -mx-4 text-center md:text-left' }, {
                allowedBlocks: [ 'flexwebsite/step' ],
                template: [
    [ 'flexwebsite/step', {} ],
    [ 'flexwebsite/step', {} ],
    [ 'flexwebsite/step', {} ],
    [ 'flexwebsite/step', {} ]
],
            } );
                            
            
            return el(Fragment, {}, [
                el('section', { ...blockProps }, el('div', { className: 'container px-4 mx-auto' }, el('div', { className: 'flex flex-wrap -mx-4' }, [el('div', { className: 'w-full md:w-1/2 px-4 mb-16 md:mb-0' }, el('div', { className: 'relative mx-auto md:ml-0 max-w-max' }, [el('img', { className: 'absolute z-10 -right-8 -top-8 w-28 md:w-auto', src: (pg_project_data_flexwebsite ? pg_project_data_flexwebsite.url : '') + 'images/circle3-yellow.svg', alt: '' }), el('img', { className: 'absolute z-10 -left-10 -bottom-8 w-28 md:w-auto', src: (pg_project_data_flexwebsite ? pg_project_data_flexwebsite.url : '') + 'images/dots3-blue.svg', alt: '' }), props.attributes.image && props.attributes.image.svg && pgCreateSVG(RawHTML, {}, pgMergeInlineSVGAttributes(propOrDefault( props.attributes.image.svg, 'image', 'svg' ), { className: 'rounded-3xl' })), props.attributes.image && !props.attributes.image.svg && propOrDefault( props.attributes.image.url, 'image', 'url' ) && el('img', { src: propOrDefault( props.attributes.image.url, 'image', 'url' ), alt: '', className: 'rounded-3xl' })])), el('div', { className: 'w-full md:w-1/2 px-4' }, [el(RichText, { tagName: 'span', className: 'inline-block py-px px-2 mb-4 text-xs leading-5 text-green-500 bg-green-100 font-medium uppercase rounded-full shadow-sm', value: propOrDefault( props.attributes.label, 'label' ), onChange: function(val) { setAttributes( {label: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] }), el(RichText, { tagName: 'h2', className: 'font-bold leading-tight mb-12 text-4xl tracking-tighter md:leading-tight md:text-5xl', value: propOrDefault( props.attributes.title, 'title' ), onChange: function(val) { setAttributes( {title: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] }), el('div', { ...innerBlocksProps })])]))),                        
                
                    el( InspectorControls, {},
                        [
                            
                        pgMediaImageControl('image', setAttributes, props, 'full', true, 'Image', '' ),
                                        
                            el(Panel, {},
                                el(PanelBody, {
                                    title: __('Block properties')
                                }, [
                                    
                                    el(TextControl, {
                                        value: props.attributes.section_id,
                                        help: __( '' ),
                                        label: __( 'Section id' ),
                                        onChange: function(val) { setAttributes({section_id: val}) },
                                        type: 'text'
                                    }),
                                    el(TextControl, {
                                        value: props.attributes.label,
                                        help: __( '' ),
                                        label: __( 'Label' ),
                                        onChange: function(val) { setAttributes({label: val}) },
                                        type: 'text'
                                    }),
                                    el(TextControl, {
                                        value: props.attributes.title,
                                        help: __( '' ),
                                        label: __( 'Title' ),
                                        onChange: function(val) { setAttributes({title: val}) },
                                        type: 'text'
                                    }),    
                                ])
                            )
                        ]
                    )                            

            ]);
        },

        save: function(props) {
            const blockProps = useBlockProps.save({ className: 'py-24 bg-white overflow-hidden', style: { backgroundPosition: 'center',backgroundImage: 'url(\'' + (pg_project_data_flexwebsite ? pg_project_data_flexwebsite.url : '') + 'images/pattern-white.svg\')' }, id: propOrDefault( props.attributes.section_id, 'section_id' ) });
            return el('section', { ...blockProps }, el('div', { className: 'container px-4 mx-auto' }, el('div', { className: 'flex flex-wrap -mx-4' }, [el('div', { className: 'w-full md:w-1/2 px-4 mb-16 md:mb-0' }, el('div', { className: 'relative mx-auto md:ml-0 max-w-max' }, [el('img', { className: 'absolute z-10 -right-8 -top-8 w-28 md:w-auto', src: (pg_project_data_flexwebsite ? pg_project_data_flexwebsite.url : '') + 'images/circle3-yellow.svg', alt: '' }), el('img', { className: 'absolute z-10 -left-10 -bottom-8 w-28 md:w-auto', src: (pg_project_data_flexwebsite ? pg_project_data_flexwebsite.url : '') + 'images/dots3-blue.svg', alt: '' }), props.attributes.image && props.attributes.image.svg && pgCreateSVG(RawHTML, {}, pgMergeInlineSVGAttributes(propOrDefault( props.attributes.image.svg, 'image', 'svg' ), { className: 'rounded-3xl' })), props.attributes.image && !props.attributes.image.svg && propOrDefault( props.attributes.image.url, 'image', 'url' ) && el('img', { src: propOrDefault( props.attributes.image.url, 'image', 'url' ), alt: '', className: 'rounded-3xl' })])), el('div', { className: 'w-full md:w-1/2 px-4' }, [el(RichText.Content, { tagName: 'span', className: 'inline-block py-px px-2 mb-4 text-xs leading-5 text-green-500 bg-green-100 font-medium uppercase rounded-full shadow-sm', value: propOrDefault( props.attributes.label, 'label' ) }), el(RichText.Content, { tagName: 'h2', className: 'font-bold leading-tight mb-12 text-4xl tracking-tighter md:leading-tight md:text-5xl', value: propOrDefault( props.attributes.title, 'title' ) }), el('div', { className: 'flex flex-wrap -mx-4 text-center md:text-left' }, el(InnerBlocks.Content, { allowedBlocks: [ 'flexwebsite/step' ] }))])])));
        }                        

    } );
} )(
    window.wp.blocks,
    window.wp.element,
    window.wp.blockEditor
);                        
